diff --git a/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiMpServicesUnitTestCommom.h b/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiMpServicesUnitTestCommom.h
index d2b1633b4d..f6bb7f904f 100644
--- a/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiMpServicesUnitTestCommom.h
+++ b/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiMpServicesUnitTestCommom.h
@@ -1,5 +1,5 @@
/** @file
- Common header file for EdkiiPeiMpServices2Ppi and EfiMpServiceProtocol unit test.
+ Common header file for EfiPeiMpServices2Ppi and EfiMpServiceProtocol unit test.
Copyright (c) 2022, Intel Corporation. All rights reserved.
@@ -23,8 +23,8 @@
#define RUN_PROCEDURE_TIMEOUT_VALUE 100000 // microseconds
typedef union {
- EDKII_PEI_MP_SERVICES2_PPI *Ppi;
- EFI_MP_SERVICES_PROTOCOL *Protocol;
+ EFI_PEI_MP_SERVICES2_PPI *Ppi;
+ EFI_MP_SERVICES_PROTOCOL *Protocol;
} MP_SERVICES;
typedef struct {
@@ -610,7 +610,7 @@ TestSwitchBSP4 (
);
/**
- Create test suite and unit tests for both EdkiiPeiMpServices2Ppi and EfiMpServiceProtocol.
+ Create test suite and unit tests for both EfiPeiMpServices2Ppi and EfiMpServiceProtocol.
@param[in] Framework A pointer to the framework that is being persisted.
@param[in] Context A pointer to the private data buffer.
diff --git a/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EdkiiPeiMpServices2PpiPeiUnitTest.inf b/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiPeiMpServices2PpiPeiUnitTest.inf
similarity index 73%
rename from UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EdkiiPeiMpServices2PpiPeiUnitTest.inf
rename to UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiPeiMpServices2PpiPeiUnitTest.inf
index 0b2ddc5585..4e692833e7 100644
--- a/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EdkiiPeiMpServices2PpiPeiUnitTest.inf
+++ b/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiPeiMpServices2PpiPeiUnitTest.inf
@@ -1,5 +1,5 @@
## @file
-# PEIM that unit tests the EdkiiPeiMpServices2Ppi
+# PEIM that unit tests the EfiPeiMpServices2Ppi
#
# Copyright (c) 2022, Intel Corporation. All rights reserved.
# SPDX-License-Identifier: BSD-2-Clause-Patent
@@ -8,7 +8,7 @@
[Defines]
INF_VERSION = 0x00010005
- BASE_NAME = EdkiiPeiMpServices2PpiPeiUnitTest
+ BASE_NAME = EfiPeiMpServices2PpiPeiUnitTest
FILE_GUID = A4914810-4D1E-445E-BD6F-F6821B852B5D
MODULE_TYPE = PEIM
VERSION_STRING = 1.0
@@ -23,7 +23,7 @@
[Sources]
EfiMpServicesUnitTestCommom.c
EfiMpServicesUnitTestCommom.h
- EdkiiPeiMpServices2PpiUnitTest.c
+ EfiPeiMpServices2PpiUnitTest.c
[Packages]
MdePkg/MdePkg.dec
@@ -40,7 +40,7 @@
UnitTestLib
[Ppis]
- gEdkiiPeiMpServices2PpiGuid ## CONSUMES
+ gEfiPeiMpServices2PpiGuid ## CONSUMES
[Depex]
- gEdkiiPeiMpServices2PpiGuid
+ gEfiPeiMpServices2PpiGuid
diff --git a/UefiCpuPkg/UefiCpuPkg.dsc b/UefiCpuPkg/UefiCpuPkg.dsc
index 5154ab04da..ca00756d30 100644
--- a/UefiCpuPkg/UefiCpuPkg.dsc
+++ b/UefiCpuPkg/UefiCpuPkg.dsc
@@ -197,7 +197,7 @@
UefiCpuPkg/Library/SmmCpuRendezvousLib/SmmCpuRendezvousLib.inf
UefiCpuPkg/Library/CpuPageTableLib/CpuPageTableLib.inf
UefiCpuPkg/Library/CpuExceptionHandlerLib/UnitTest/PeiCpuExceptionHandlerLibUnitTest.inf
- UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EdkiiPeiMpServices2PpiPeiUnitTest.inf
+ UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiPeiMpServices2PpiPeiUnitTest.inf
UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiMpServiceProtocolDxeUnitTest.inf
UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiMpServiceProtocolDynamicCmdUnitTest.inf {
diff --git a/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EdkiiPeiMpServices2PpiUnitTest.c b/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiPeiMpServices2PpiUnitTest.c
similarity index 91%
rename from UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EdkiiPeiMpServices2PpiUnitTest.c
rename to UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiPeiMpServices2PpiUnitTest.c
index 5c42a81d29..85f30b44ca 100644
--- a/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EdkiiPeiMpServices2PpiUnitTest.c
+++ b/UefiCpuPkg/Test/UnitTest/EfiMpServicesPpiProtocol/EfiPeiMpServices2PpiUnitTest.c
@@ -1,5 +1,5 @@
/** @file
- PEI Module to test APIs defined in EdkiiPeiMpServices2Ppi.
+ PEI Module to test APIs defined in EfiPeiMpServices2Ppi.
Copyright (c) 2022, Intel Corporation. All rights reserved.
@@ -11,23 +11,23 @@
#include
#include "EfiMpServicesUnitTestCommom.h"
-#define UNIT_TEST_NAME "EdkiiPeiMpServices2Ppi Unit Test"
+#define UNIT_TEST_NAME "EfiPeiMpServices2Ppi Unit Test"
#define UNIT_TEST_VERSION "0.1"
/**
- Get EDKII_PEI_MP_SERVICES2_PPI pointer.
+ Get EFI_PEI_MP_SERVICES2_PPI pointer.
- @param[out] MpServices Pointer to the buffer where EDKII_PEI_MP_SERVICES2_PPI is stored.
+ @param[out] MpServices Pointer to the buffer where EFI_PEI_MP_SERVICES2_PPI is stored.
- @retval EFI_SUCCESS EDKII_PEI_MP_SERVICES2_PPI interface is returned
- @retval EFI_NOT_FOUND EDKII_PEI_MP_SERVICES2_PPI interface is not found
+ @retval EFI_SUCCESS EFI_PEI_MP_SERVICES2_PPI interface is returned
+ @retval EFI_NOT_FOUND EFI_PEI_MP_SERVICES2_PPI interface is not found
**/
EFI_STATUS
MpServicesUnitTestGetMpServices (
OUT MP_SERVICES *MpServices
)
{
- return PeiServicesLocatePpi (&gEdkiiPeiMpServices2PpiGuid, 0, NULL, (VOID **)&MpServices->Ppi);
+ return PeiServicesLocatePpi (&gEfiPeiMpServices2PpiGuid, 0, NULL, (VOID **)&MpServices->Ppi);
}
/**
@@ -375,7 +375,7 @@ TestStartupAllCPUs3 (
}
/**
- Create test suite and unit tests only for EdkiiPeiMpServices2Ppi.
+ Create test suite and unit tests only for EfiPeiMpServices2Ppi.
@param[in] Framework A pointer to the framework that is being persisted.
@param[in] Context A pointer to the private data buffer.
@@ -384,7 +384,7 @@ TestStartupAllCPUs3 (
@retval Others Create test suite and unit tests unsuccessfully.
**/
EFI_STATUS
-AddTestCaseOnlyForEdkiiPeiMpServices2Ppi (
+AddTestCaseOnlyForEfiPeiMpServices2Ppi (
IN UNIT_TEST_FRAMEWORK_HANDLE Framework,
IN MP_SERVICE_UT_CONTEXT *Context
)
@@ -412,7 +412,7 @@ AddTestCaseOnlyForEdkiiPeiMpServices2Ppi (
/**
Standard PEIM entry point for unit test execution from PEI.
- Initialize the unit test framework, suite, and unit tests for the EdkiiPeiMpServices2Ppi and run the unit test.
+ Initialize the unit test framework, suite, and unit tests for the EfiPeiMpServices2Ppi and run the unit test.
@param[in] FileHandle Handle of the file being invoked.
@param[in] PeiServices Pointer to PEI Services table.
@@ -446,16 +446,16 @@ PeiEntryPoint (
}
//
// Create test suite and unit tests only for EdkiiPeiMpServices2Ppi.
//
- Status = AddTestCaseOnlyForEdkiiPeiMpServices2Ppi (Framework, &Context);
+ Status = AddTestCaseOnlyForEfiPeiMpServices2Ppi (Framework, &Context);
if (EFI_ERROR (Status)) {
- DEBUG ((DEBUG_ERROR, "Failed in AddTestCaseOnlyForEdkiiPeiMpServices2Ppi. Status = %r\n", Status));
+ DEBUG ((DEBUG_ERROR, "Failed in AddTestCaseOnlyForEfiPeiMpServices2Ppi. Status = %r\n", Status));
goto EXIT;
}
//
// Create test suite and unit tests for both EdkiiPeiMpServices2Ppi and EfiMpServiceProtocol.
//
Status = AddCommonTestCase (Framework, &Context);
if (EFI_ERROR (Status)) {
@@ -446,16 +446,16 @@ PeiEntryPoint (
}
//
- // Create test suite and unit tests only for EdkiiPeiMpServices2Ppi.
+ // Create test suite and unit tests only for EfiPeiMpServices2Ppi.
//
@@ -446,16 +446,16 @@ PeiEntryPoint (
}
//
- // Create test suite and unit tests for both EdkiiPeiMpServices2Ppi and EfiMpServiceProtocol.
+ // Create test suite and unit tests for both EfiPeiMpServices2Ppi and EfiMpServiceProtocol.
//
Status = AddCommonTestCase (Framework, &Context);